==> nextcloud-app-notes-3.1.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/notes/l10n/lt_LT.js <==
OC.L10N.register(
    "notes",
    {
    "Notes" : "Užrašai",
    "The last viewed note cannot be accessed. " : "Nepavyksta gauti prieigos prie paskutinių rodytų užrašų.",
    "The notes folder is not accessible: %s" : "Užrašų aplankas yra nepasiekiamas: %s",
    "New note" : "Nauji užrašai",
    "Encryption Error" : "Šifravimo klaida",
    "Error" : "Klaida",
    "Distraction-free notes and writing" : "Neblaškantys užrašai ir rašymas",
    "Settings" : "Nustatymai",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Yra neįrašytų užrašų. Išėjus iš šio puslapio, visi pakeitimai bus atmesti!",
    "Folder to store your notes" : "Aplankas, kuriame saugoti jūsų užrašus",
    "path to notes" : "kelias į užrašus",
    "File extension for new notes" : "Naujų užrašų failo prievardis",
    "All notes" : "Visi užrašai",
    "Categories" : "Kategorijos",
    "Loading …" : "Įkeliama…",
    "Today" : "Šiandien",
    "Yesterday" : "Vakar",
    "This week" : "Šią savaitę",
    "Last week" : "Praeitą savaitę",
    "This month" : "Šį mėnesį",
    "Last month" : "Praeitą mėnesį",
    "Delete note" : "Ištrinti užrašus",
    "Deleted {title}" : "{title} ištrinti",
    "Remove from favorites" : "Šalinti iš mėgstamų",
    "Add to favorites" : "Pridėti į mėgstamus",
    "Empty note" : "Tušti užrašai",
    "Write …" : "Rašykite…",
    "Details" : "Išsamiau",
    "Preview" : "Peržiūra",
    "Edit" : "Taisyti",
    "Exit full screen" : "Išeiti iš viso ekrano",
    "Full screen" : "Visas ekranas",
    "Save failed. Click to retry." : "Nepavyko įrašyti. Spustelėkite, norėdami bandyti dar kartą.",
    "Set category" : "Nustatyti kategoriją",
    "Category" : "Kategorija",
    "Uncategorized" : "Nekategorizuotas",
    "Click here to save manually" : "Spustelėkite čia norėdami įrašyti rankiniu būdu",
    "Saving failed!" : "Įrašymas nepavyko!",
    "Last modified: {date}" : "Paskutinis modifikavimas: {date}",
    "Note has unsaved changes" : "Užrašuose yra neįrašytų pakeitimų.",
    "Subcategory" : "Subkategorija",
    "_%n word_::_%n words_" : ["%n žodis","%n žodžiai","%n žodžių","%n žodis"],
    "Write down your thoughts without any distractions." : "Užsirašykite savo mintis be jokio blaškymosi.",
    "Android app" : "Android programėlė",
    "iOS app" : "iOS programėlė",
    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Galite sukurti subkategorijas, naudodami \"/\" kaip skirtuką tarp viršesnės kategorijos ir subkategorijos, pvz., “{parent}/{sub}”.",
    "See JavaScript console for details." : "Išsamesnei informacijai, žiūrėkite JavaScript pultą.",
    "Updating settings has failed." : "Nepavyko atnaujinti nustatymų.",
    "Development Mode" : "Plėtotojo veiksena"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-app-notes-3.4.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/notes/l10n/lt_LT.js <==
OC.L10N.register(
    "notes",
    {
    "Notes" : "Užrašai",
    "The last viewed note cannot be accessed. " : "Nepavyksta gauti prieigos prie paskutinių rodytų užrašų.",
    "The notes folder is not accessible: %s" : "Užrašų aplankas yra nepasiekiamas: %s",
    "Error" : "Klaida",
    "New note" : "Nauji užrašai",
    "Distraction-free notes and writing" : "Neblaškantys užrašai ir rašymas",
    "Settings" : "Nustatymai",
    "Deleted {title}" : "{title} ištrinti",
    "Undo Delete" : "Atšaukti ištrynimą",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Yra neįrašytų užrašų. Išėjus iš šio puslapio, visi pakeitimai bus atmesti!",
    "Folder to store your notes" : "Aplankas, kuriame saugoti jūsų užrašus",
    "path to notes" : "kelias į užrašus",
    "File extension for new notes" : "Naujų užrašų failo prievardis",
    "All notes" : "Visi užrašai",
    "Categories" : "Kategorijos",
    "Loading …" : "Įkeliama…",
    "Today" : "Šiandien",
    "Yesterday" : "Vakar",
    "This week" : "Šią savaitę",
    "Last week" : "Praeitą savaitę",
    "This month" : "Šį mėnesį",
    "Last month" : "Praeitą mėnesį",
    "Rename" : "Pervadinti",
    "Delete note" : "Ištrinti užrašus",
    "Remove from favorites" : "Šalinti iš mėgstamų",
    "Add to favorites" : "Pridėti į mėgstamus",
    "Empty note" : "Tušti užrašai",
    "Write …" : "Rašykite…",
    "Details" : "Išsamiau",
    "Preview" : "Peržiūra",
    "Edit" : "Taisyti",
    "Exit full screen" : "Išeiti iš viso ekrano",
    "Full screen" : "Visas ekranas",
    "Save failed. Click to retry." : "Nepavyko įrašyti. Spustelėkite, norėdami bandyti dar kartą.",
    "Set category" : "Nustatyti kategoriją",
    "Category" : "Kategorija",
    "Uncategorized" : "Nekategorizuoti",
    "Click here to save manually" : "Spustelėkite čia norėdami įrašyti rankiniu būdu",
    "Saving failed!" : "Įrašymas nepavyko!",
    "Last modified: {date}" : "Paskutinis modifikavimas: {date}",
    "Note has unsaved changes" : "Užrašuose yra neįrašytų pakeitimų.",
    "Subcategory" : "Subkategorija",
    "_%n word_::_%n words_" : ["%n žodis","%n žodžiai","%n žodžių","%n žodis"],
    "Write down your thoughts without any distractions." : "Užsirašykite savo mintis be jokio blaškymosi.",
    "Android app" : "Android programėlė",
    "iOS app" : "iOS programėlė",
    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Galite sukurti subkategorijas, naudodami \"/\" kaip skirtuką tarp viršesnės kategorijos ir subkategorijos, pvz., “{parent}/{sub}”.",
    "Updating settings has failed." : "Nepavyko atnaujinti nustatymų.",
    "Updating the note's category has failed. Is the target directory writable?" : "Nepavyko atnaujinti užrašų kategorijos. Ar paskirties katalogas yra skirtas rašymui?",
    "Development Mode" : "Plėtotojo veiksena"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
